@@ -34,10 +34,6 @@ class Scanner:
                 'ignore_paths': None,
                 'show_progress': False,
             }
-        if options.get('sgrep_extensions'):
-            self.sgrep_extensions = options.get('sgrep_extensions')
-        else:
-            self.sgrep_extensions = []
         if options.get('ignore_extensions'):
             self.ignore_extensions = options.get('ignore_extensions')
         else:
@@ -87,15 +83,11 @@ class Scanner:
 
     def validate_file(self, path):
         """Check if we should scan the file."""
-        ignore_paths = any(pp in path.as_posix() for pp in self.ignore_paths)
+        ignore_paths = any(
+            Path(pp).as_posix() in path.as_posix() for pp in self.ignore_paths)
         ignore_files = path.name in self.ignore_filenames
         ignore_exts = path.suffix.lower() in self.ignore_extensions
-        if self.sgrep_extensions:
-            valid_exts = path.suffix.lower() in self.sgrep_extensions
-        else:
-            # Do not use extension check when no extensions are supplied
-            valid_exts = True
-        if (ignore_paths or ignore_files or ignore_exts or not valid_exts):
+        if (ignore_paths or ignore_files or ignore_exts):
             return False
         if not path.exists() or not path.is_file():
             return False
